Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2430)

Unified Diff: chrome/browser/resources/chromeos/switch_access/testable_tree_walker.js

Issue 2777203006: Added auto-scan, made some small changes to how prefs are stored, refactored. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/chromeos/switch_access/testable_tree_walker.js
diff --git a/chrome/browser/resources/chromeos/switch_access/testable_switch_access.js b/chrome/browser/resources/chromeos/switch_access/testable_tree_walker.js
similarity index 67%
rename from chrome/browser/resources/chromeos/switch_access/testable_switch_access.js
rename to chrome/browser/resources/chromeos/switch_access/testable_tree_walker.js
index c5cdde736627254bd5b0ed86d0aea4e907974889..47470e4606524dff2fa361c604d2143d3eab64d8 100644
--- a/chrome/browser/resources/chromeos/switch_access/testable_switch_access.js
+++ b/chrome/browser/resources/chromeos/switch_access/testable_tree_walker.js
@@ -3,16 +3,15 @@
// found in the LICENSE file.
/**
* Subclass of SwitchAccess that exposes SwitchAccess's methods for testing.
*/
-let TestableSwitchAccess = function() {
- SwitchAccess.call(this);
+let TestableTreeWalker = function() {
+ AutomationTreeWalker.call(this);
};
-TestableSwitchAccess.prototype = {
- __proto__: SwitchAccess.prototype,
-
- init_: function() {},
+TestableTreeWalker.prototype = {
+ __proto__: AutomationTreeWalker.prototype,
getNextNode: function(node) {
return this.getNextNode_(node);
@@ -3,16 +3,15 @@
// found in the LICENSE file.
/**
- * Subclass of SwitchAccess that exposes SwitchAccess's methods for testing.
+ * Subclass of AutomationTreeWalker that exposes AutomationTreeWalker's methods
+ * for testing.
*/

Powered by Google App Engine
This is Rietveld 408576698